cmd

package
v1.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 9, 2025 License: Apache-2.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func RunRootCmd

func RunRootCmd(cmd *cobra.Command, args []string) error

Types

type AgentPool added in v1.8.0

type AgentPool struct {
	ID                 string   `json:"id"`
	Name               string   `json:"name"`
	AgentCount         int      `json:"agent_count"`
	OrganizationScoped bool     `json:"organization_scoped"`
	Organization       string   `json:"organization"`
	Workspaces         []string `json:"workspaces"`
	AllowedWorkspaces  []string `json:"allowed_workspaces"`
}

type Plan added in v1.7.0

type Plan struct {
	ID                        string `json:"id"`
	HasChanges                bool   `json:"has_changes"`
	Status                    string `json:"status"`
	ResourceAdditions         int    `json:"resource_additions"`
	ResourceChanges           int    `json:"resource_changes"`
	ResourceDestructions      int    `json:"resource_destructions"`
	ResourceImports           int    `json:"resource_imports"`
	ChangedResourceProperties any    `json:"changed_resource_properties"`
}

type Policy

type Policy struct {
	ID             string `json:"id"`
	Name           string `json:"name"`
	Kind           string `json:"kind"`
	Enforce        string `json:"enforce"`
	PolicySetCount int    `json:"policy_set_count"`
}

type PolicyCheck added in v1.3.2

type PolicyCheck struct {
	ID     string            `json:"id"`
	Result PolicyCheckResult `json:"result"`
	Status tfe.PolicyStatus  `json:"status"`
	Scope  tfe.PolicyScope   `json:"scope"`
}

type PolicyCheckResult added in v1.3.2

type PolicyCheckResult struct {
	AdvisoryFailed int  `json:"advisory_failed"`
	HardFailed     int  `json:"hard_failed"`
	Passed         int  `json:"passed"`
	Result         bool `json:"result"`
	SoftFailed     int  `json:"soft_failed"`
	TotalFailed    int  `json:"total_failed"`
	Sentinel       any  `json:"sentinel"`
}

type PolicySet added in v1.3.2

type PolicySet struct {
	ID                  string   `json:"id"`
	Name                string   `json:"name"`
	Kind                string   `json:"kind"`
	Global              bool     `json:"global"`
	Workspaces          []string `json:"workspaces"`
	WorkspaceCount      int      `json:"workspace_count"`
	WorkspaceExclusions []string `json:"workspace_exclusions"`
	Projects            []string `json:"projects"`
	ProjectCount        int      `json:"project_count"`
	Policies            []string `json:"policies"`
	PolicyCount         int      `json:"policy_count"`
}

type PrivateProviderDetail added in v1.5.0

type PrivateProviderDetail struct {
	RegistryProvider
	ProviderLatestVersion string             `json:"provider_latest_version"`
	ProviderPlatforms     []ProviderPlatform `json:"provider_platforms"`
}

type ProviderPlatform added in v1.5.0

type ProviderPlatform struct {
	ID       string `json:"id"`
	OS       string `json:"os"`
	Arch     string `json:"arch"`
	Filename string `json:"filename"`
}

type RegistryModule added in v1.5.0

type RegistryModule struct {
	ID                  string                   `json:"id"`
	Name                string                   `json:"name"`
	Provider            string                   `json:"provider"`
	RegistryName        tfe.RegistryName         `json:"registry_name"`
	Namespace           string                   `json:"namespace"`
	PublishingMechanism tfe.PublishingMechanism  `json:"publishing_mechanism"`
	Status              tfe.RegistryModuleStatus `json:"status"`
	TestConfig          bool                     `json:"test_config"`
	VCSRepo             string                   `json:"vcs_repo"`
	ModuleLatestVersion string                   `json:"module_latest_version"`
}

type RegistryProvider added in v1.5.0

type RegistryProvider struct {
	ID           string           `json:"id"`
	Name         string           `json:"name"`
	Namespace    string           `json:"namespace"`
	RegistryName tfe.RegistryName `json:"registry_name"`
}

type Run

type Run struct {
	ID            string `json:"id"`
	WorkspaceID   string `json:"workspace_id"`
	WorkspaceName string `json:"workspace_name"`
	Status        string `json:"status"`
	CreatedAt     string `json:"created_at"`
	RunDuration   string `json:"run_duration"`
	PlanID        string `json:"plan_id"`
}

type Tag added in v1.2.0

type Tag struct {
	Name          string `json:"name"`
	ID            string `json:"id"`
	InstanceCount int    `json:"instance_count"`
}

type Team

type Team struct {
	Name      string `json:"name"`
	ID        string `json:"id"`
	UserCount int    `json:"user_count"`
}

type TeamDetail

type TeamDetail struct {
	Team  Team   `json:"team"`
	Users []User `json:"user_list"`
}

type User

type User struct {
	ID     string                           `json:"user_id"`
	Email  string                           `json:"email"`
	Status tfe.OrganizationMembershipStatus `json:"status"`
}

type Variable

type Variable struct {
	ID          string           `json:"id"`
	Key         string           `json:"key"`
	Value       string           `json:"value"`
	Description string           `json:"description"`
	Category    tfe.CategoryType `json:"category"`
	HCL         bool             `json:"hcl"`
	Sensitive   bool             `json:"sensitive"`
}

type Variables

type Variables struct {
	Variables []Variable `json:"variables"`
}

type Workspace

type Workspace struct {
	Name             string   `json:"name"`
	ID               string   `json:"id"`
	Locked           bool     `json:"locked"`
	ExecutionMode    string   `json:"execution_mode"`
	TerraformVersion string   `json:"terraform_version"`
	Tags             []string `json:"tags"`
	AgentPoolID      string   `json:"agent_pool_id"`
}

type WorkspaceDetail

type WorkspaceDetail struct {
	Workspace
	CreatedDaysAgo         string `json:"created_days_ago"`
	UpdatedDaysAgo         string `json:"updated_days_ago"`
	LastRemoteRunDaysAgo   string `json:"last_remote_run_days_ago"`
	LastStateUpdateDaysAgo string `json:"last_state_update_days_ago"`
	AverageRunDuration     string `json:"average_run_duration"`
}

WorkspaceDetail for -detail flag with list

type WorkspaceLite

type WorkspaceLite struct {
	WorkspaceID   string `json:"workspace_id"`
	WorkspaceName string `json:"workspace_name"`
}

type WorkspaceLock

type WorkspaceLock struct {
	Name   string `json:"name"`
	ID     string `json:"id"`
	Locked bool   `json:"locked"`
}

type WorkspaceVar

type WorkspaceVar struct {
	WorkspaceLite
	Variable Variable `json:"variable"`
}

type WorkspaceVars

type WorkspaceVars struct {
	WorkspaceLite
	Variables []Variable `json:"variables"`
}

Jump to